var express = require('express');
var path = require('path');
var Sequelize = require('sequelize');
var bodyParser = require('body-parser');

var userDb = require('./models/users')();
var activitiesDb = require('./models/activities')();

var sequelize = new Sequelize('masters_testdb', 'root', 'root', {
  dialect: "sqlite", // or 'sqlite', 'postgres', 'mariadb'
  port:    3306 // or 5432 (for postgres)
});

sequelize.authenticate().complete(function(err) {
  if (!!err) {
    console.log ('Unable to connect to the database:', err);
  } else {
    console.log ('Database connection has been established successfully.');

    userDb.init (sequelize);
    activitiesDb.init(sequelize);

    sequelize.sync ({ force: false }).complete (function (err) {
      if (!!err) {
        console.log ('An error occurred syncing tables:', err);
      } else {
        console.log ('tables synced!');

        // add default data
        var sample_data = require('./models/userdata.js');
        userDb.loadData (sample_data);
      }
    });
  }
});

var app = express ();

app.use(bodyParser());

app.use('/assets', express.static('public'));

var users = require('./controllers/users');
var activities = require('./controllers/activities');

// hacky shortcut to get the userid for the activity route
app.use('/api/users/:userId/activities', function (req,res,next) {
  req.app.set('activityUserId', req.params.userId);
  next ();
});
app.use('/api/users/:userId/activities', activities);

app.use('/api/users', users);

app.use('/', function (req, res){
  res.sendfile('./public/pacemaker.html');
});

app.set('userDb', userDb);
app.set('activitiesDb', activitiesDb);

app.listen(8080);
console.log ("pacemaker-node app is listening on port 8080");